@@ -130,8 +130,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
 
     def close(self):
         # Don't fire signals for editors that have destroyed their controls.
-        QtCore.QObject.disconnect(self._qt4_editor_area,
-                QtCore.SIGNAL('hasFocus'), self._qt4_editor_focus)
+        self._qt4_editor_area.editor_has_focus.disconnect(self._qt4_editor_focus)
 
         self._qt4_editor_area.clear()
 
@@ -143,20 +142,14 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
     def create_initial_layout(self, parent):
         self._qt4_editor_area = editor_area = SplitTabWidget(parent)
 
-        QtCore.QObject.connect(editor_area, QtCore.SIGNAL('hasFocus'),
-                               self._qt4_editor_focus)
+        editor_area.editor_has_focus.connect(self._qt4_editor_focus)
 
         # We are interested in focus changes but we get them from the editor
         # area rather than qApp to allow the editor area to restrict them when
         # needed.
-        QtCore.QObject.connect(
-            editor_area, QtCore.SIGNAL('focusChanged(QWidget *,QWidget *)'),
-            self._qt4_view_focus_changed)
-
-        QtCore.QObject.connect(self._qt4_editor_area,
-                QtCore.SIGNAL('tabTextChanged(QWidget *, QString)'),
-                self._qt4_editor_title_changed)
+        editor_area.focus_changed.connect(self._qt4_view_focus_changed)
 
+        editor_area.tabTextChanged.connect(self._qt4_editor_title_changed)
         editor_area.new_window_request.connect(self._qt4_new_window_request)
         editor_area.tab_close_request.connect(self._qt4_tab_close_request)
         editor_area.tab_window_changed.connect(self._qt4_tab_window_changed)
@@ -202,7 +195,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         view_ids = [v.id for v in self.window.views if self.contains_view(v)]
 
         # Everything else is provided by QMainWindow.
-        state = str(self.window.control.saveState())
+        state = self.window.control.saveState()
 
         return (0, (view_ids, state))
 
@@ -292,7 +285,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         self._qt4_editor_area.restoreState(editor_layout, resolve_id)
 
     def get_toolkit_memento(self):
-        return (0, dict(geometry=str(self.window.control.saveGeometry())))
+        return (0, {'geometry' : self.window.control.saveGeometry()})
 
     def set_toolkit_memento(self, memento):
         if hasattr(memento, 'toolkit_data'):
@@ -304,6 +297,8 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
                     if geometry is not None:
                         self.window.control.restoreGeometry(geometry)
 
+    def is_editor_area_visible(self):
+        return self._qt4_editor_area.isVisible()
 
     ###########################################################################
     # Private interface.
@@ -336,7 +331,8 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
     def _qt4_active_editor_changed(self, old, new):
         """ Handle change of active editor """
         # Reset tab title to foreground color
-        self._qt4_editor_area.setTabTextColor(new.control)
+        if new is not None:
+            self._qt4_editor_area.setTabTextColor(new.control)
 
     def _qt4_view_focus_changed(self, old, new):
         """ Handle the change of focus for a view. """
@@ -501,10 +497,9 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             dw = QtGui.QDockWidget(view.name, self.window.control)
             dw.setWidget(_ViewContainer(size, self.window.control))
             dw.setObjectName(view.id)
-            dw.connect(dw.toggleViewAction(), QtCore.SIGNAL('toggled(bool)'),
-                    self._qt4_handle_dock_visibility)
-            dw.connect(dw, QtCore.SIGNAL('visibilityChanged(bool)'),
-                    self._qt4_handle_dock_visibility)
+            dw.toggleViewAction().toggled.connect(
+                self._qt4_handle_dock_visibility)
+            dw.visibilityChanged.connect(self._qt4_handle_dock_visibility)
 
             # Save the dock window.
             view._qt4_dock = dw
@@ -520,7 +515,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             view.window = self.window
 
             try:
-                view.control = view.create_control(self.window.control)
+                view.control = view.create_control(dw.widget())
             except:
                 # Tidy up if the view couldn't be created.
                 delattr(view, '_qt4_dock')
